<?php
/**
 * This is the entrypoint for the locrMAPS for WooCommerce WordPress plugin.
 *
 * @package locrMAPS for WooCommerce
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMapsForWooCommerce\DDD\ValueObjects;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the DPI
 *
 * @property-read int $Value The value.
 */
final class Dpi {
	/**
	 * The constructor.
	 *
	 * @param int $value The value.
	 * @throws \InvalidArgumentException If the value is less than or equal to 0.
	 */
	public function __construct( private int $value = 300 ) {
		if ( $value <= 0 ) {
			throw new \InvalidArgumentException( 'The dpi must be greater than 0' );
		}
	}

	/**
	 * The magick getter.
	 *
	 * @param string $name The name of the property.
	 * @throws \InvalidArgumentException If the property does not exist.
	 */
	public function __get( string $name ): mixed {
		return match ( $name ) {
			'Value' => $this->value,
			default => throw new \InvalidArgumentException( "Property $name does not exist" ), // phpcs:ignore
		};
	}
}
